@@ -49,6 +49,7 @@ def configure(file_name):
 # Initializes all GUI widgets
 class MainInterface:
     def __init__(self):
+        padding=5
         self.window = Toplevel()
         folder = Frame(self.window)
         folder.grid(row=0, column=1, sticky=N)
@@ -58,16 +59,16 @@ class MainInterface:
         self.button_frame.grid(row=1, column=0)
 
         self.frameNumber = Label(self.button_frame, text="Frame number")
-        self.frameNumber.grid(row=0, column=1)
+        self.frameNumber.grid(row=0, column=1, padx=padding)
         self.forward = Button(self.button_frame, text=">",
                               command=lambda: load_frame(current_frame_number+1, self.window, self.fbox))
-        self.forward.grid(row=1, column=3, sticky=E)
+        self.forward.grid(row=1, column=3, sticky=E, padx=padding)
         self.forward = Button(self.button_frame, text=">>",
                               command=lambda: load_frame(len(frames_in) - 1, self.window, self.fbox))
-        self.forward.grid(row=1, column=4, sticky=E)
+        self.forward.grid(row=1, column=4, sticky=E, padx=padding)
         self.back = Button(self.button_frame, text="<",
                            command=lambda: load_frame(current_frame_number-1, self.window, self.fbox))
-        self.back.grid(row=1, column=1, sticky=W)
+        self.back.grid(row=1, column=1, sticky=W, padx=padding)
         self.back = Button(self.button_frame, text="<<", command=lambda: load_frame(0, self.window, self.fbox))
         self.back.grid(row=1, column=0, sticky=W)
 
@@ -145,8 +146,8 @@ class MainInterface:
         video.grid(sticky=N, pady = 10)
         video_key = Label(video_player, text='\n\n  Keyboard shortcuts for video navigation: \n p = Pause/Play'
                                              '\n\n After pressing pause:'
-                                             '\n o = +2 frames \n e = +10 frames \n w = +1 second'
-                                             '\n\n t = -2 frames \n s = -10 frames \n x = -1 second'
+                                             '\n o = +2 frames \n i = +10 frames \n u = +1 second'
+                                             '\n\n r = -2 frames \n e = -10 frames \n w = -1 second'
                                              '\n\n q = Close video window \n\n')
         video_key.grid(sticky=W)
         update = Button(video_player, text='Show current video frame',
