@@ -30,7 +30,6 @@ def importSLEAPbottomUP(inifile, dataFolder, currIDList):
     videoFolder = os.path.join(projectPath, 'videos')
     outputDfFolder = os.path.join(projectPath, 'csv', 'input_csv')
     animalsNo = len(currIDList)
-    print(animalsNo)
     bpNamesCSVPath = os.path.join(projectPath, 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv')
     poseEstimationSetting = config.get('create ensemble settings', 'pose_estimation_body_parts')
     print('Converting .slp into csv dataframes...')
@@ -110,6 +109,8 @@ def importSLEAPbottomUP(inifile, dataFolder, currIDList):
             ### check if all animals exist
             splitOutRow = np.array_split(outRow, animalsinCurrFrame)
             splitOutRow = [l.tolist() for l in splitOutRow]
+            for newValue in range(len(splitOutRow)):
+                splitOutRow[newValue][-1] = newValue
             animalsExist = []
             for animalList in splitOutRow:
                 animalsExist.append(animalList[-1])
